unit SDL_joystick;

{ ---------------------------------------
    SDL - Simple DirectMedia Layer
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002  Sam Lantinga

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Sam Lantinga
    slouken@libsdl.org
----------------------------------------- }

{ -------------------------------
  Unit for FreePascal
  Rero2@fumi <rero2@yuumu.org>

  $Id: SDL_joystick.pp,v 1.1 2002/07/11 17:21:46 rero2 Exp $
-------------------------------- }

interface

  uses SDL_types;

  { -----
    Get the current state of a POV hat on a joystick
    The return value is one of the following positions:
  ----- }
  const
    SDL_HAT_CENTERED = $00;
    SDL_HAT_UP = $01;
    SDL_HAT_RIGHT = $02;
    SDL_HAT_DOWN = $04;
    SDL_HAT_LEFT = $08;
    SDL_HAT_RIGHTUP = (SDL_HAT_RIGHT or SDL_HAT_UP);
    SDL_HAT_RIGHTDOWN = (SDL_HAT_RIGHT or SDL_HAT_DOWN);
    SDL_HAT_LEFTUP = (SDL_HAT_LEFT or SDL_HAT_UP);
    SDL_HAT_LEFTDOWN = (SDL_HAT_LEFT or SDL_HAT_DOWN);

  type
    pballdelta = ^balldelta;
    balldelta = record
	dx: Integer;
	dy: Integer;
    end;

    PSDL_Joystick = ^SDLJoystick;
    SDLJoystick = record
        { Device index }
	index: Uint8;
	{ Joystick name - system dependent }
	name: PChar;

	{ Number of axis controls on the joystick }
	naxes: Integer;
	{ Current axis states }
	axes: Sint16;

	{ Number of hats on the joystick }
	nhats: Integer;
	{ Current hat states }
	hats: PByte;
	
	{ Number of trackballs on the joystick }
	nballs: Integer;
	{ Current ball motion deltas }
        balls: pballdelta;
	
	{ Number of buttons on the joystick }
	nbuttons: Integer;
	{ Current button states }
	buttons: PByte;

	{ Driver dependent information }
	{ struct joystick_hwdata *hwdata; }
        hwdata: Pointer;

	{ Reference count for multiple opens }
	ref_count: Integer;
    end;



    { -----
     * Count the number of joysticks attached to the system
    ----- }
    function SDL_NumJoysticks: Integer; cdecl; external 'SDL';

    { -----
     * Get the implementation dependent name of a joystick.
     * This can be called before any joysticks are opened.
     * If no name can be found, this function returns NULL.
    ----- }
    function SDL_JoystickName(device_index: Integer): PChar; cdecl; external 'SDL';

    { -----
     * Open a joystick for use - the index passed as an argument refers to
     * the N'th joystick on the system.  This index is the value which will
     * identify this joystick in future joystick events.
     *
     * This function returns a joystick identifier,
     * or NULL if an error occurred.
    ----- }
    function SDL_JoystickOpen(device_index: Integer): PSDL_Joystick; cdecl; external 'SDL';

    { -----
     * Returns 1 if the joystick has been opened, or 0 if it has not.
    ----- }
    function SDL_JoystickOpened(device_index: Integer): Integer; cdecl; external 'SDL';

    { -----
     * Get the device index of an opened joystick.
    ----- }
    function SDL_JoystickIndex(joystick: PSDL_Joystick): Integer; cdecl; external 'SDL';

    { -----
     * Get the number of general axis controls on a joystick
    ----- }
    function SDL_JoystickNumAxes(joystick: PSDL_Joystick): Integer; cdecl; external 'SDL';

    { -----
     * Get the number of trackballs on a joystick
     * Joystick trackballs have only relative motion events associated
     * with them and their state cannot be polled.
    ----- }
    function SDL_JoystickNumBalls(joystick: PSDL_Joystick): Integer; cdecl; external 'SDL';

    { -----
     * Get the number of POV hats on a joystick
    ----- }
    function SDL_JoystickNumHats(joystick: PSDL_Joystick): Integer; cdecl; external 'SDL';

    { -----
     * Get the number of buttons on a joystick
    ----- }
    function SDL_JoystickNumButtons(joystick: PSDL_Joystick): Integer; cdecl; external 'SDL';

    { -----
     * Update the current state of the open joysticks.
     * This is called automatically by the event loop if any joystick
     * events are enabled.
    ----- }
    procedure SDL_JoystickUpdate; cdecl; external 'SDL';

    { -----
     * Enable/disable joystick event polling.
     * If joystick events are disabled, you must call SDL_JoystickUpdate()
     * yourself and check the state of the joystick when you want joystick
     * information.
     * The state can be one of SDL_QUERY, SDL_ENABLE or SDL_IGNORE.
    ----- }
    function SDL_JoystickEventState(state: Integer): Integer; cdecl; external 'SDL';

    { -----
     * Get the current state of an axis control on a joystick
     * The state is a value ranging from -32768 to 32767.
     * The axis indices start at index 0.
    ----- }
    function SDL_JoystickGetAxis(joystick: PSDL_Joystick; axis: Integer): Sint16; cdecl; external 'SDL';

    { -----
     * The hat indices start at index 0.
    ----- }
    function  SDL_JoystickGetHat(joystick: PSDL_Joystick; hat: Integer): Uint8; cdecl; external 'SDL';

    { -----
     * Get the ball axis change since the last poll
     * This returns 0, or -1 if you passed it invalid parameters.
     * The ball indices start at index 0.
    ----- }
    function SDL_JoystickGetBall(joystick: PSDL_Joystick; ball: Integer; dx: PInteger; dy: PInteger): Integer; cdecl; external 'SDL';

    { -----
     * Get the current state of a button on a joystick
     * The button indices start at index 0.
    ----- }
    function SDL_JoystickGetButton(joystick: PSDL_Joystick; button: Integer): Uint8; cdecl; external 'SDL';

    { -----
     * Close a joystick previously opened with SDL_JoystickOpen()
    ----- }
    procedure SDL_JoystickClose(joystick: PSDL_Joystick); cdecl; external 'SDL';



implementation

end.
