unit SDLmixer;

{ ---------------------------------------
    SDL_mixer:  An audio mixer library based on the SDL library
    Copyright (C) 1997, 1998, 1999, 2000, 2001  Sam Lantinga

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Sam Lantinga
    slouken@libsdl.org
----------------------------------------- }

{ -------------------------------
  Unit for FreePascal
  Rero2@fumi <rero2@yuumu.org>

  $Id: SDLmixer.pp,v 1.1 2002/07/11 17:21:46 rero2 Exp $
-------------------------------- }

interface

  uses SDL, SDL_types, SDL__rwops, SDL_audio;


  Const
    MIX_CHANNELS = 8;
    MIX_DEFAULT_FREQUENCY = 22050;
{$ifdef SDL_BYTEORDER = SDL_LIL_ENDIAN }
    MIX_DEFAULT_FORMAT = AUDIO_S16LSB;
{$else}
    MIX_DEFAULT_FORMAT = AUDIO_S16MSB;
{$endif}
    MIX_DEFAULT_CHANNELS = 2;
    { Volume of a chunk }
    MIX_MAX_VOLUME = 128;
    MIX_CHANNEL_POST = -2;
    MIX_EFFECTSMAXSPEED = 'MIX_EFFECTSMAXSPEED';


  Type
    Mix_Fading = (MIX_NO_FADING,
	          MIX_FADING_OUT,
	          MIX_FADING_IN);
    Mix_MusicType = (MUS_NONE,
                     MUS_CMD,
                     MUS_WAV,
                     MUS_MOD,
                     MUS_MID,
                     MUS_OGG,
                     MUS_MP3);
    PUint8 = ^Uint8;
    PUint16 = ^Uint16;
    PMix_Chunk = ^Mix_Chunk;
    Mix_Chunk = record
      allocated: Integer;
      abuf: PByte;
      alen: Cardinal;
      { Per-sample volume, 0-128 }
      volume: Uint8;
    end;

    PMix_Music = ^Mix_Music;
    Mix_Music = record
      musictype: Mix_MusicType;
      data: Pointer;
{ - - - - - - - - - - - - -
union
#ifdef CMD_MUSIC
		MusicCMD *cmd;
#endif
#ifdef WAV_MUSIC
		WAVStream *wave;
#endif
#ifdef MOD_MUSIC
		UNIMOD *module;
#endif
#ifdef MID_MUSIC
#ifdef USE_TIMIDITY_MIDI
		MidiSong *midi;
#endif
#ifdef USE_NATIVE_MIDI
		NativeMidiSong *nativemidi;
#endif
#endif
#ifdef OGG_MUSIC
		OGG_music *ogg;
#endif
#ifdef MP3_MUSIC
		SMPEG *mp3;
#endif
- - - - - - - - - - - - - }
      fading: Mix_Fading;
      fade_step: Integer;
      fade_steps: Integer;
      error: Integer;
    end;

    PMix_EffectFunc_t = ^Mix_EffectFunc_t;
    Mix_EffectFunc_t = procedure(chan:Integer; stream:Pointer; len:Integer; udata:Pointer);
    PMix_EffectDone_t = ^Mix_EffectDone_t;
    Mix_EffectDone_t = procedure(chan:Integer; udata:Pointer);



    function Mix_OpenAudio(frequency:Integer; format:Uint16; channels:Integer; chunksize:Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_AllocateChannels(numchans:Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_QuerySpec(frequency:PInteger; format:PUint16; channels:PInteger): Integer; cdecl; external 'SDL_mixer';
    function Mix_LoadWAV_RW(src: PSDL_RWops; freesrc:Integer): PMix_Chunk; cdecl; external 'SDL_mixer';
    function Mix_LoadMUS(filename:PChar): PMix_Music; cdecl; external 'SDL_mixer';
    function Mix_QuickLoad_WAV(mem:PUint8): PMix_Chunk; cdecl; external 'SDL_mixer';
    function Mix_QuickLoad_RAW(mem:PUint8; len:Uint32): PMix_Chunk; cdecl; external 'SDL_mixer';
    procedure Mix_FreeChunk(chunk: PMix_Chunk); cdecl; external 'SDL_mixer';
    procedure Mix_FreeMusic(music: PMix_Music); cdecl; external 'SDL_mixer';
    function Mix_GetMusicType(music: PMix_Music): Mix_MusicType; cdecl; external 'SDL_mixer';
{ ----- No support
    procedure Mix_SetPostMix(void (*mix_func)
                             (void *udata, Uint8 *stream, int len), void *arg); cdecl; external 'SDL_mixer';
    procedure Mix_HookMusic(void (*mix_func)
                          (void *udata, Uint8 *stream, int len), void *arg); cdecl; external 'SDL_mixer';
    procedure Mix_HookMusicFinished(void (*music_finished)(void)); cdecl; external 'SDL_mixer';
    function Mix_GetMusicHookData: Pointer; cdecl; external 'SDL_mixer';
    procedure Mix_ChannelFinished(void (*channel_finished)(int channel)); cdecl; external 'SDL_mixer';
---------------------- }
    function Mix_RegisterEffect(chan: Integer; f: Mix_EffectFunc_t;
                                d: Mix_EffectDone_t; arg: Pointer): Integer; cdecl; external 'SDL_mixer';
    function Mix_UnregisterEffect(channel: Integer;  f:Mix_EffectFunc_t): Integer; cdecl; external 'SDL_mixer';
    function Mix_UnregisterAllEffects(channel: Integer): Integer; cdecl; external 'SDL_mixer';
    
    function Mix_SetPanning(channel: Integer; left: Uint8; right: Uint8): Integer; cdecl; external 'SDL_mixer';
    function Mix_SetPosition(channel: Integer; angle: Sint16; distance: Uint8): Integer; cdecl; external 'SDL_mixer';
    function Mix_SetDistance(channel: Integer; distance: Uint8): Integer; cdecl; external 'SDL_mixer';
    function Mix_SetReverseStereo(channel: Integer; flip: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_ReserveChannels(num: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_GroupChannel(which: Integer; tag: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_GroupChannels(fromch: Integer; toch: Integer; tag: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_GroupAvailable(tag: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_GroupCount(tag: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_GroupOldest(tag: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_GroupNewer(tag: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_PlayChannelTimed(channel: Integer; chunk: PMix_Chunk; loops: Integer; ticks: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_PlayMusic(music: PMix_Music; loops: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_FadeInMusic(music: pMix_Music; loops: Integer; ms: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_FadeInMusicPos(music: PMix_Music; loops: Integer; ms: Integer; position: Double): Integer; cdecl; external 'SDL_mixer';
    function Mix_FadeInChannelTimed(channel: Integer; chunk: PMix_Chunk; loops: Integer; ms: Integer; ticks:Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_Volume(channel: Integer; volume: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_VolumeChunk(chunk: PMix_Chunk; volume: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_VolumeMusic(volume: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_HaltChannel(channel: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_HaltGroup(tag: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_HaltMusic: Integer; cdecl; external 'SDL_mixer';
    function Mix_ExpireChannel(channel: Integer; ticks: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_FadeOutChannel(which: Integer; ms: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_FadeOutGroup(tag: Integer; ms: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_FadeOutMusic(ms: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_FadingMusic: Mix_Fading; cdecl; external 'SDL_mixer';
    function Mix_FadingChannel(which: Integer): Mix_Fading; cdecl; external 'SDL_mixer';
    procedure Mix_Pause(channel: Integer); cdecl; external 'SDL_mixer';
    procedure Mix_Resume(channel: Integer); cdecl; external 'SDL_mixer';
    function Mix_Paused(channel: Integer): Integer; cdecl; external 'SDL_mixer';
    procedure Mix_PauseMusic; cdecl; external 'SDL_mixer';
    procedure Mix_ResumeMusic; cdecl; external 'SDL_mixer';
    procedure Mix_RewindMusic; cdecl; external 'SDL_mixer';
    function Mix_PausedMusic: Integer; cdecl; external 'SDL_mixer';
    function Mix_SetMusicPosition(position: Double): Integer; cdecl; external 'SDL_mixer';
    function Mix_Playing(channel: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_PlayingMusic: Integer; cdecl; external 'SDL_mixer';
    function Mix_SetMusicCMD(command: PChar): Integer; cdecl; external 'SDL_mixer';
    function Mix_SetSynchroValue(value: Integer): Integer; cdecl; external 'SDL_mixer';
    function Mix_GetSynchroValue: Integer; cdecl; external 'SDL_mixer';
    function Mix_GetChunk(channel: Integer): PMix_Chunk; cdecl; external 'SDL_mixer';
    procedure Mix_CloseAudio; cdecl; external 'SDL_mixer';


    function Mix_LoadWAV(filename: PChar): PMix_Chunk;
    function Mix_PlayChannel(channel: Integer; chunk: PMix_Chunk; loops: Integer): Integer;
    function Mix_FadeInChannel(channel: Integer; chunk: PMix_Chunk; loops: Integer; ms: Integer): Integer;



implementation

function Mix_LoadWAV(filename: PChar): PMix_Chunk;
begin
  Mix_LoadWAV := Mix_LoadWAV_RW(SDL_RWFromFile(filename, 'rb'), 1);
end;

function Mix_PlayChannel(channel: Integer; chunk: PMix_Chunk; loops: Integer): Integer;
begin
  Mix_PlayChannel :=  Mix_PlayChannelTimed(channel,chunk,loops,-1);
end;

function Mix_FadeInChannel(channel: Integer; chunk: PMix_Chunk; loops: Integer; ms: Integer): Integer;
begin
  Mix_FadeInChannel :=  Mix_FadeInChannelTimed(channel,chunk,loops,ms,-1);
end;

end.
